summaryrefslogtreecommitdiffstats
path: root/Source/WebCore/platform/chromium/PopupMenuChromium.cpp
diff options
context:
space:
mode:
authorBen Murdoch <benm@google.com>2011-06-02 12:07:03 +0100
committerBen Murdoch <benm@google.com>2011-06-10 10:47:21 +0100
commit2daae5fd11344eaa88a0d92b0f6d65f8d2255c00 (patch)
treee4964fbd1cb70599f7718ff03e50ea1dab33890b /Source/WebCore/platform/chromium/PopupMenuChromium.cpp
parent87bdf0060a247bfbe668342b87e0874182e0ffa9 (diff)
downloadexternal_webkit-2daae5fd11344eaa88a0d92b0f6d65f8d2255c00.zip
external_webkit-2daae5fd11344eaa88a0d92b0f6d65f8d2255c00.tar.gz
external_webkit-2daae5fd11344eaa88a0d92b0f6d65f8d2255c00.tar.bz2
Merge WebKit at r84325: Initial merge by git.
Change-Id: Ic1a909300ecc0a13ddc6b4e784371d2ac6e3d59b
Diffstat (limited to 'Source/WebCore/platform/chromium/PopupMenuChromium.cpp')
-rw-r--r--Source/WebCore/platform/chromium/PopupMenuChromium.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/Source/WebCore/platform/chromium/PopupMenuChromium.cpp b/Source/WebCore/platform/chromium/PopupMenuChromium.cpp
index e83ebe4..af97ecf 100644
--- a/Source/WebCore/platform/chromium/PopupMenuChromium.cpp
+++ b/Source/WebCore/platform/chromium/PopupMenuChromium.cpp
@@ -571,10 +571,10 @@ void PopupContainer::refresh(const IntRect& targetControlRect)
location.move(0, targetControlRect.height());
listBox()->updateFromElement();
- // Store the original height to check if we need to request the location.
- int originalHeight = height();
+ // Store the original size to check if we need to request the location.
+ IntSize originalSize = size();
IntRect widgetRect = layoutAndCalculateWidgetRect(targetControlRect.height(), location);
- if (originalHeight != widgetRect.height())
+ if (originalSize != widgetRect.size())
setFrameRect(widgetRect);
invalidate();